--- setup.py.orig	2022-11-25 15:21:16 UTC
+++ setup.py
@@ -2,7 +2,7 @@
 from os import path as op
 from sys import version_info
 
-from setuptools import setup, find_packages
+from setuptools import setup
 
 from pyradio import version, __project__, __license__
 
@@ -27,8 +27,11 @@ meta = dict(
     author='Ben Dowling',
     author_email='ben.m.dowling@gmail.com',
     url=' http://github.com/coderholic/pyradio',
-    packages=find_packages(),
-    include_package_data=True,
+    packages=['pyradio'],
+    package_dir={'pyradio':'pyradio'},
+    package_data={
+      'pyradio': ['stations.csv', 'config', 'themes/*'],
+    },
     entry_points={
         'console_scripts': [
             'pyradio = pyradio.main:shell',



# 1) converters/py-rencode: Fails to configure if cython is installed
# 2) make setup.py test command work via test_suite directive
# 3) Honour/respect user CFLAGS
# https://bugs.freebsd.org/bugzilla/show_bug.cgi?id=233561

--- setup.py.orig	2018-10-21 17:41:35 UTC
+++ setup.py
@@ -29,19 +29,14 @@ from distutils.errors import CCompilerError, Distutils
 from setuptools import setup
 from setuptools.extension import Extension
 
-try:
-    from Cython.Build import build_ext
-    from Cython.Build import cythonize
-except ImportError as ex:
-    from setuptools.command.build_ext import build_ext
-    cythonize = False
+from setuptools.command.build_ext import build_ext
+cythonize = False
 
 source_ext = ".pyx" if cythonize else ".c"
 
 ext_modules = [
     Extension(
         "rencode._rencode",
-        extra_compile_args=["-O3"],
         sources=["rencode/rencode" + source_ext],
     ),
 ]
@@ -92,5 +87,6 @@ setup(
   url="https://github.com/aresch/rencode",
   cmdclass={'build_ext': optional_build_ext},
   ext_modules=ext_modules,
-  setup_requires=['setuptools', 'wheel'],
+  setup_requires=['setuptools'],
+  test_suite='tests',
 )



--- setup.py.orig	2022-03-25 16:23:32 UTC
+++ setup.py
@@ -35,7 +35,7 @@ setup(name=__pkg_name__.replace("_", "-"),
       version=get_version(),
       url='https://github.com/nanoporetech/{}'.format(__pkg_name__),
       install_requires=installation_requirements,
-      packages=find_packages(),
+      packages=find_packages(exclude=['test']),
       package_data={__pkg_name__: ['vbz_plugin/*.so', 'vbz_plugin/*.dylib', 'vbz_plugin/*.dll']},
       python_requires='>=3.6',
       entry_points={'console_scripts': [



--- scripts/simple_phaser.py.orig	2021-01-23 17:25:56 UTC
+++ scripts/simple_phaser.py
@@ -108,7 +108,7 @@ class SimplePhaser:
         return informativeHets, informativeCoords, informativeIndexes
     
     def getRefPairedAllele(self, anchorIndex, pairedIndex):
-#         print "\t".join([str(anchorIndex), str(pairedIndex - anchorIndex  - 1), str(len(self.ldMap.dVals)),str(len(self.ldMap.dVals[anchorIndex]))]) # prints intermarker counts
+#         print("\t".join([str(anchorIndex), str(pairedIndex - anchorIndex  - 1), str(len(self.ldMap.dVals)),str(len(self.ldMap.dVals[anchorIndex]))]) # prints intermarker counts)
         if (pairedIndex - anchorIndex - 1) >= len(self.ldMap.dVals[anchorIndex]):
             pRef = random.uniform(0,1)
             if pRef > 0.5:
@@ -166,8 +166,8 @@ class SimplePhaser:
                 altHap = temp 
             
             if pairedAllele not in [ref,alt]:
-                print "pairedAllele not ref or alt " + ref + " " + alt
-                print pairedAllele               
+                print("pairedAllele not ref or alt " + ref + " " + alt)
+                print(pairedAllele)
          
         return phasedAlleles, informativeCoords
             
@@ -182,7 +182,7 @@ class SimplePhaser:
             elif candidateHap[i].upper() == phasedHaps[1][i].upper():
                 currentMatch = 1
             else:
-                print "ERROR: " + candidateHap[i] + " does not match " + phasedHaps[0][i] + " or " + phasedHaps[1][i] + "\t" + self.ldMap.coords[i] + "\t" + self.ldMap.refs[i] + "\t" + self.ldMap.alts[i]
+                print("ERROR: " + candidateHap[i] + " does not match " + phasedHaps[0][i] + " or " + phasedHaps[1][i] + "\t" + self.ldMap.coords[i] + "\t" + self.ldMap.refs[i] + "\t" + self.ldMap.alts[i])
 #                 # randomly assign match
 #                 p0 = random.uniform(0,1)
 #                 if p0 > 0.5:



--- buildtools/wafsamba/samba_autoconf.py.orig	2019-09-04 10:53:16 UTC
+++ buildtools/wafsamba/samba_autoconf.py
@@ -573,7 +573,7 @@ def library_flags(self, libs):
 
 
 @conf
-def CHECK_LIB(conf, libs, mandatory=False, empty_decl=True, set_target=True, shlib=False):
+def CHECK_LIB(conf, libs, mandatory=False, empty_decl=True, set_target=True, shlib=False, msg=None):
     '''check if a set of libraries exist as system libraries
 
     returns the sublist of libs that do exist as a syslib or []
@@ -593,11 +593,29 @@ int foo()
             ret.append(lib)
             continue
 
+        if msg is None:
+            msg = 'Checking for library %s' % lib
+
         (ccflags, ldflags, cpppath) = library_flags(conf, lib)
+
         if shlib:
-            res = conf.check(features='c cshlib', fragment=fragment, lib=lib, uselib_store=lib, cflags=ccflags, ldflags=ldflags, uselib=lib.upper(), mandatory=False)
+            res = conf.check(features='c cshlib',
+                             fragment=fragment,
+                             lib=lib,
+                             uselib_store=lib,
+                             cflags=ccflags,
+                             ldflags=ldflags,
+                             uselib=lib.upper(),
+                             mandatory=False,
+                             msg=msg)
         else:
-            res = conf.check(lib=lib, uselib_store=lib, cflags=ccflags, ldflags=ldflags, uselib=lib.upper(), mandatory=False)
+            res = conf.check(lib=lib,
+                             uselib_store=lib,
+                             cflags=ccflags,
+                             ldflags=ldflags,
+                             uselib=lib.upper(),
+                             mandatory=False,
+                             msg=msg)
 
         if not res:
             if mandatory:
@@ -944,5 +962,5 @@ def SAMBA_CHECK_UNDEFINED_SYMBOL_FLAGS(c
         conf.env.undefined_ldflags = conf.ADD_LDFLAGS('-Wl,-no-undefined', testflags=True)
 
         if (conf.env.undefined_ignore_ldflags == [] and
-            conf.CHECK_LDFLAGS(['-undefined', 'dynamic_lookup'])):
+            conf.CHECK_LDFLAGS(['-undefined', 'dynamic_lookup'] + conf.env.WERROR_CFLAGS)):
             conf.env.undefined_ignore_ldflags = ['-undefined', 'dynamic_lookup']



from locust import HttpLocust, TaskSet, task


def index(l):
    l.client.get("/")

def stats(l):
    l.client.get("/stats/requests")

class UserTasks(TaskSet):
    # one can specify tasks like this
    tasks = [index, stats]
    
    # but it might be convenient to use the @task decorator
    @task
    def page404(self):
        self.client.get("/does_not_exist")
    
class WebsiteUser(HttpLocust):
    """
    Locust user class that does requests to the locust web server running on localhost
    """
    host = "http://127.0.0.1:8089"
    min_wait = 2000
    max_wait = 5000
    task_set = UserTasks



--- UM/View/GL/OpenGL.py.orig	2020-03-08 11:52:09 UTC
+++ UM/View/GL/OpenGL.py
@@ -19,6 +19,8 @@ from UM.View.GL.OpenGLContext import OpenGLContext
 from UM.i18n import i18nCatalog  # To make dialogs translatable.
 i18n_catalog = i18nCatalog("uranium")
 
+import OpenGL.GL as gl
+
 if TYPE_CHECKING:
     from UM.Mesh.MeshData import MeshData
 
@@ -59,7 +61,8 @@ class OpenGL:
             Logger.log("e", "Startup failed due to OpenGL context creation failing")
             QMessageBox.critical(None, i18n_catalog.i18nc("@message", "Failed to Initialize OpenGL", "Could not initialize an OpenGL context. This program requires OpenGL 2.0 or higher. Please check your video card drivers."))
             sys.exit(1)
-        self._gl = context.versionFunctions(profile) # type: Any #It's actually a protected class in PyQt that depends on the implementation of your graphics card.
+        self._gl = gl
+#        self._gl = context.versionFunctions(profile) # type: Any #It's actually a protected class in PyQt that depends on the implementation of your graphics card.
         if not self._gl:
             Logger.log("e", "Startup failed due to OpenGL initialization failing")
             QMessageBox.critical(None, i18n_catalog.i18nc("@message", "Failed to Initialize OpenGL", "Could not initialize OpenGL. This program requires OpenGL 2.0 or higher. Please check your video card drivers."))
@@ -75,14 +78,13 @@ class OpenGL:
             QMessageBox.critical(None, i18n_catalog.i18nc("Critical OpenGL Extensions Missing", "Critical OpenGL extensions are missing. This program requires support for Framebuffer Objects. Please check your video card drivers."))
             sys.exit(1)
 
-        self._gl.initializeOpenGLFunctions()
+#        self._gl.initializeOpenGLFunctions()
 
         self._gpu_vendor = OpenGL.Vendor.Other #type: int
-        vendor_string = self._gl.glGetString(self._gl.GL_VENDOR)
+        vendor_string = self._gl.glGetString(self._gl.GL_VENDOR).decode("utf-8")
         if vendor_string is None:
             vendor_string = "Unknown"
         vendor_string = vendor_string.lower()
-
         if "nvidia" in vendor_string:
             self._gpu_vendor = OpenGL.Vendor.NVidia
         elif "amd" in vendor_string or "ati" in vendor_string:



We cannot really distinguish between USB and non-USB here,
as port[2] is 'n/a' on FreeBSD.

--- plugins/USBPrinting/USBPrinterOutputDeviceManager.py.orig	2020-07-23 19:29:25 UTC
+++ plugins/USBPrinting/USBPrinterOutputDeviceManager.py
@@ -123,8 +123,6 @@
                 port = (port.device, port.description, port.hwid)
             if not port[2]:  # HWID may be None if the device is not USB or the system doesn't report the type.
                 continue
-            if only_list_usb and not port[2].startswith("USB"):
-                continue
 
             # To prevent cura from messing with serial ports of other devices,
             # filter by regular expressions passed in as environment variables.



--- docs/conf.py.orig	2022-12-10 15:31:47 UTC
+++ docs/conf.py
@@ -17,7 +17,7 @@ import sys, os
 # add these directories to sys.path here. If the directory is relative to the
 # documentation root, use os.path.abspath to make it absolute, like shown here.
 #sys.path.insert(0, os.path.abspath('.'))
-sys.path.insert(0, os.path.abspath('.'))
+sys.path.insert(0, os.path.abspath(os.path.join('..')))
 import spotipy
 
 # -- General configuration -----------------------------------------------------



--- aksetup_helper.py.orig	2012-12-16 01:56:27 UTC
+++ aksetup_helper.py
@@ -1,6 +1,6 @@
 # dealings with ez_setup ------------------------------------------------------
-import distribute_setup
-distribute_setup.use_setuptools()
+#import distribute_setup
+#distribute_setup.use_setuptools()
 
 import setuptools
 from setuptools import Extension



--- setup.py.orig	2020-06-25 14:36:51 UTC
+++ setup.py
@@ -35,7 +35,7 @@ setup(
         "cadquery.contrib",
         "cadquery.occ_impl",
         "cadquery.plugins",
-        "tests",
+        "cadquery.tests",
     ],
     include_package_data=True,
     zip_safe=False,



Obtained from:	https://github.com/sbmlteam/libsbml/commit/4f01a15fde1d8afa9eaffb4c13dfc83a3404f183 (based on)

--- src/bindings/python/doc-converter/rewrite_pydoc.py.orig	2020-11-25 11:03:01 UTC
+++ src/bindings/python/doc-converter/rewrite_pydoc.py
@@ -118,7 +118,273 @@ import re
 import sys
 import os
 import textwrap
-from formatter import NullWriter, AbstractFormatter
+try:
+    from formatter import NullWriter, AbstractFormatter
+except Exception:
+    # issue 173 these classes have been removed in 3.10, so 
+    # as per the 3.10 release notes: Existing users should copy whatever 
+    # classes they use into their code. (Contributed by Dong-hee Na and 
+    # Terry J. Reedy in bpo-42299.)
+    #
+    # So here they are:
+
+
+    class NullWriter:
+        """Minimal writer interface to use in testing & inheritance.
+
+        A writer which only provides the interface definition; no actions are
+        taken on any methods.  This should be the base class for all writers
+        which do not need to inherit any implementation methods.
+
+        """
+        def __init__(self): pass
+        def flush(self): pass
+        def new_alignment(self, align): pass
+        def new_font(self, font): pass
+        def new_margin(self, margin, level): pass
+        def new_spacing(self, spacing): pass
+        def new_styles(self, styles): pass
+        def send_paragraph(self, blankline): pass
+        def send_line_break(self): pass
+        def send_hor_rule(self, *args, **kw): pass
+        def send_label_data(self, data): pass
+        def send_flowing_data(self, data): pass
+        def send_literal_data(self, data): pass
+
+    class AbstractFormatter:
+        """The standard formatter.
+
+        This implementation has demonstrated wide applicability to many writers,
+        and may be used directly in most circumstances.  It has been used to
+        implement a full-featured World Wide Web browser.
+
+        """
+
+        #  Space handling policy:  blank spaces at the boundary between elements
+        #  are handled by the outermost context.  "Literal" data is not checked
+        #  to determine context, so spaces in literal data are handled directly
+        #  in all circumstances.
+
+        def __init__(self, writer):
+            self.writer = writer            # Output device
+            self.align = None               # Current alignment
+            self.align_stack = []           # Alignment stack
+            self.font_stack = []            # Font state
+            self.margin_stack = []          # Margin state
+            self.spacing = None             # Vertical spacing state
+            self.style_stack = []           # Other state, e.g. color
+            self.nospace = 1                # Should leading space be suppressed
+            self.softspace = 0              # Should a space be inserted
+            self.para_end = 1               # Just ended a paragraph
+            self.parskip = 0                # Skipped space between paragraphs?
+            self.hard_break = 1             # Have a hard break
+            self.have_label = 0
+
+        def end_paragraph(self, blankline):
+            if not self.hard_break:
+                self.writer.send_line_break()
+                self.have_label = 0
+            if self.parskip < blankline and not self.have_label:
+                self.writer.send_paragraph(blankline - self.parskip)
+                self.parskip = blankline
+                self.have_label = 0
+            self.hard_break = self.nospace = self.para_end = 1
+            self.softspace = 0
+
+        def add_line_break(self):
+            if not (self.hard_break or self.para_end):
+                self.writer.send_line_break()
+                self.have_label = self.parskip = 0
+            self.hard_break = self.nospace = 1
+            self.softspace = 0
+
+        def add_hor_rule(self, *args, **kw):
+            if not self.hard_break:
+                self.writer.send_line_break()
+            self.writer.send_hor_rule(*args, **kw)
+            self.hard_break = self.nospace = 1
+            self.have_label = self.para_end = self.softspace = self.parskip = 0
+
+        def add_label_data(self, format, counter, blankline = None):
+            if self.have_label or not self.hard_break:
+                self.writer.send_line_break()
+            if not self.para_end:
+                self.writer.send_paragraph((blankline and 1) or 0)
+            if isinstance(format, str):
+                self.writer.send_label_data(self.format_counter(format, counter))
+            else:
+                self.writer.send_label_data(format)
+            self.nospace = self.have_label = self.hard_break = self.para_end = 1
+            self.softspace = self.parskip = 0
+
+        def format_counter(self, format, counter):
+            label = ''
+            for c in format:
+                if c == '1':
+                    label = label + ('%d' % counter)
+                elif c in 'aA':
+                    if counter > 0:
+                        label = label + self.format_letter(c, counter)
+                elif c in 'iI':
+                    if counter > 0:
+                        label = label + self.format_roman(c, counter)
+                else:
+                    label = label + c
+            return label
+
+        def format_letter(self, case, counter):
+            label = ''
+            while counter > 0:
+                counter, x = divmod(counter-1, 26)
+                # This makes a strong assumption that lowercase letters
+                # and uppercase letters form two contiguous blocks, with
+                # letters in order!
+                s = chr(ord(case) + x)
+                label = s + label
+            return label
+
+        def format_roman(self, case, counter):
+            ones = ['i', 'x', 'c', 'm']
+            fives = ['v', 'l', 'd']
+            label, index = '', 0
+            # This will die of IndexError when counter is too big
+            while counter > 0:
+                counter, x = divmod(counter, 10)
+                if x == 9:
+                    label = ones[index] + ones[index+1] + label
+                elif x == 4:
+                    label = ones[index] + fives[index] + label
+                else:
+                    if x >= 5:
+                        s = fives[index]
+                        x = x-5
+                    else:
+                        s = ''
+                    s = s + ones[index]*x
+                    label = s + label
+                index = index + 1
+            if case == 'I':
+                return label.upper()
+            return label
+
+        def add_flowing_data(self, data):
+            if not data: return
+            prespace = data[:1].isspace()
+            postspace = data[-1:].isspace()
+            data = " ".join(data.split())
+            if self.nospace and not data:
+                return
+            elif prespace or self.softspace:
+                if not data:
+                    if not self.nospace:
+                        self.softspace = 1
+                        self.parskip = 0
+                    return
+                if not self.nospace:
+                    data = ' ' + data
+            self.hard_break = self.nospace = self.para_end = \
+                            self.parskip = self.have_label = 0
+            self.softspace = postspace
+            self.writer.send_flowing_data(data)
+
+        def add_literal_data(self, data):
+            if not data: return
+            if self.softspace:
+                self.writer.send_flowing_data(" ")
+            self.hard_break = data[-1:] == '\n'
+            self.nospace = self.para_end = self.softspace = \
+                        self.parskip = self.have_label = 0
+            self.writer.send_literal_data(data)
+
+        def flush_softspace(self):
+            if self.softspace:
+                self.hard_break = self.para_end = self.parskip = \
+                                self.have_label = self.softspace = 0
+                self.nospace = 1
+                self.writer.send_flowing_data(' ')
+
+        def push_alignment(self, align):
+            if align and align != self.align:
+                self.writer.new_alignment(align)
+                self.align = align
+                self.align_stack.append(align)
+            else:
+                self.align_stack.append(self.align)
+
+        def pop_alignment(self):
+            if self.align_stack:
+                del self.align_stack[-1]
+            if self.align_stack:
+                self.align = align = self.align_stack[-1]
+                self.writer.new_alignment(align)
+            else:
+                self.align = None
+                self.writer.new_alignment(None)
+
+        def push_font(self, font):
+            size, i, b, tt = font
+            if self.softspace:
+                self.hard_break = self.para_end = self.softspace = 0
+                self.nospace = 1
+                self.writer.send_flowing_data(' ')
+            if self.font_stack:
+                csize, ci, cb, ctt = self.font_stack[-1]
+                if size is AS_IS: size = csize
+                if i is AS_IS: i = ci
+                if b is AS_IS: b = cb
+                if tt is AS_IS: tt = ctt
+            font = (size, i, b, tt)
+            self.font_stack.append(font)
+            self.writer.new_font(font)
+
+        def pop_font(self):
+            if self.font_stack:
+                del self.font_stack[-1]
+            if self.font_stack:
+                font = self.font_stack[-1]
+            else:
+                font = None
+            self.writer.new_font(font)
+
+        def push_margin(self, margin):
+            self.margin_stack.append(margin)
+            fstack = filter(None, self.margin_stack)
+            if not margin and fstack:
+                margin = fstack[-1]
+            self.writer.new_margin(margin, len(fstack))
+
+        def pop_margin(self):
+            if self.margin_stack:
+                del self.margin_stack[-1]
+            fstack = filter(None, self.margin_stack)
+            if fstack:
+                margin = fstack[-1]
+            else:
+                margin = None
+            self.writer.new_margin(margin, len(fstack))
+
+        def set_spacing(self, spacing):
+            self.spacing = spacing
+            self.writer.new_spacing(spacing)
+
+        def push_style(self, *styles):
+            if self.softspace:
+                self.hard_break = self.para_end = self.softspace = 0
+                self.nospace = 1
+                self.writer.send_flowing_data(' ')
+            for style in styles:
+                self.style_stack.append(style)
+            self.writer.new_styles(tuple(self.style_stack))
+
+        def pop_style(self, n=1):
+            del self.style_stack[-n:]
+            self.writer.new_styles(tuple(self.style_stack))
+
+        def assert_line_data(self, flag=1):
+            self.nospace = self.hard_break = not flag
+            self.para_end = self.parskip = self.have_label = 0
+    
+
 try:
     from htmllib import HTMLParser
 except Exception:



--- indiweb/driver.py	2021-09-05 00:47:09.163136000 -0500
+++ indiweb/driver.py	2021-09-05 00:47:30.642233000 -0500
@@ -5,7 +5,7 @@
 import xml.etree.ElementTree as ET
 
 # Default INDI data directory
-INDI_DATA_DIR = "/usr/share/indi/"
+INDI_DATA_DIR = "%%LOCALBASE%%/share/indi/"
 
 
 class DeviceDriver:



--- scripts/ldmap.py.orig	2021-01-23 17:32:15 UTC
+++ scripts/ldmap.py
@@ -29,10 +29,10 @@ class MapMaker:
     coordinates of the haplotype marker genomic positions.
     '''
     def __init__(self, markerFilename, haplotypesFilename):
-        print "reading haplotype base coordinates ...."
+        print("reading haplotype base coordinates ....")
         self.coords, self.coordIndexes, self.refs, self.alts = self.readMarkers(markerFilename)
 #         self.haplotypes = self.readHaplotypes(haplotypesFilename)
-        print "reading haplotype panel ...."
+        print("reading haplotype panel ....")
         self.markerCalls = self.readHaplotypes(haplotypesFilename, transpose = True)
     
     # reads from a vcf file of defined positions representing the haplotype data    
@@ -118,7 +118,7 @@ class MapMaker:
         # 1) COLLECT MARGINALS AND IDENTIFY SITES THAT ARE POLYMORPHIC
         # If a site has only one allele in the haplotype panel it is not informative, so it won't be used
         # in LD calculations.  We may want to consider setting some minimum threshold for a minor allele frequency.
-        print "collecting marginal allele counts and identifying polymorphic sites from haplotype panel ...."
+        print("collecting marginal allele counts and identifying polymorphic sites from haplotype panel ....")
         for index in range(0,len(self.markerCalls)):
             ref = self.refs[index]
             alt = self.alts[index]
@@ -152,7 +152,7 @@ class MapMaker:
         log.write("Num non-polymorphic sites: " + str(numNonpolymorphicSites) + "\n")
                
         # 2) CALCULATE D FOR POLYMORPHIC SITES COMPARED WITH N SITES TO THE RIGHT THAT ARE POLYMORPHIC
-        print "calculating D between polymorphic sites and their neighbors ...."
+        print("calculating D between polymorphic sites and their neighbors ....")
         dVals = []
         for i in range(0, len(polymorphicIndexes)):   # the last coordinate won't have any partners
             index_i = polymorphicIndexes[i]
@@ -244,7 +244,7 @@ class LDMap:
         return ldMap
         
     def save(self, filename):
-        print "saving ldmap to " + filename
+        print("saving ldmap to " + filename)
         ldMapFile = open(filename, 'w')
         ldMapFile.write("\t".join(["COORD","REF","ALT","PAIRED_ALLELES"]) + "\n")
         for i in range(0,len(self.coords)):



# This locust test script example will simulate a user
# browsing the Locust documentation on https://docs.locust.io/

import random
from locust import HttpLocust, TaskSquence, seq_task, task
from pyquery import PyQuery


class BrowseDocumentationSequence(TaskSquence):
    def on_start(self):
        self.urls_on_current_page = self.toc_urls

    # assume all users arrive at the index page
    @seq_task(1)
    def index_page(self):
        r = self.client.get("/")
        pq = PyQuery(r.content)
        link_elements = pq(".toctree-wrapper a.internal")
        self.toc_urls = [
            l.attrib["href"] for l in link_elements
        ]

    @seq_task(2)
    @task(50)
    def load_page(self, url=None):
        url = random.choice(self.toc_urls)
        r = self.client.get(url)
        pq = PyQuery(r.content)
        link_elements = pq("a.internal")
        self.urls_on_current_page = [
            l.attrib["href"] for l in link_elements
        ]

    @seq_task(3)
    @task(30)
    def load_sub_page(self):
        url = random.choice(self.urls_on_current_page)
        r = self.client.get(url)


class AwesomeUser(HttpLocust):
    task_set = BrowseDocumentationSequence
    host = "https://docs.locust.io/en/latest/"

    # we assume someone who is browsing the Locust docs,
    # generally has a quite long waiting time (between
    # 20 and 600 seconds), since there's a bunch of text
    # on each page
    min_wait = 20 * 1000
    max_wait = 600 * 1000



--- setup.py.orig	2017-10-14 15:52:28 UTC
+++ setup.py
@@ -14,34 +14,11 @@ if sys.version_info < (2, 6):
     print("THIS MODULE REQUIRES PYTHON 2.6, 2.7, OR 3.3+. YOU ARE CURRENTLY USING PYTHON {0}".format(sys.version))
     sys.exit(1)
 
-
-FILES_TO_MARK_EXECUTABLE = ["flac-linux-x86", "flac-linux-x86_64", "flac-mac", "flac-win32.exe"]
-
-
-class InstallWithExtraSteps(install):
-    def run(self):
-        install.run(self)  # do the original install steps
-
-        # mark the FLAC executables as executable by all users (this fixes occasional issues when file permissions get messed up)
-        for output_path in self.get_outputs():
-            if os.path.basename(output_path) in FILES_TO_MARK_EXECUTABLE:
-                log.info("setting executable permissions on {}".format(output_path))
-                stat_info = os.stat(output_path)
-                os.chmod(
-                    output_path,
-                    stat_info.st_mode |
-                    stat.S_IRUSR | stat.S_IXUSR |  # owner can read/execute
-                    stat.S_IRGRP | stat.S_IXGRP |  # group can read/execute
-                    stat.S_IROTH | stat.S_IXOTH  # everyone else can read/execute
-                )
-
-
 setup(
     name="SpeechRecognition",
     version=speech_recognition.__version__,
     packages=["speech_recognition"],
     include_package_data=True,
-    cmdclass={"install": InstallWithExtraSteps},
 
     # PyPI metadata
     author=speech_recognition.__author__,



--- multiqc/multiqc.py.orig	2019-11-25 15:53:22 UTC
+++ multiqc/multiqc.py
@@ -11,16 +11,25 @@ from __future__ import print_function
 
 import base64
 import click
+import os
+import sys
+
+if 'LC_ALL' in os.environ and 'LANG' in os.environ:
+    import click
+else:
+    print('multiqc: LC_ALL and LANG must be set to a UTF-8 character set')
+    print('in your environment in order for the click module to function.')
+    print('E.g. export LC_ALL=en_US.UTF-8 or setenv LC_ALL en_US.UTF-8')
+    sys.exit()
+
 from distutils import version
 from distutils.dir_util import copy_tree
 import errno
 import io
 import jinja2
-import os
 import re
 import shutil
 import subprocess
-import sys
 import tempfile
 import traceback
 



--- build/mixxx.py	2018-04-15 13:30:27.000000000 -0500
+++ build/mixxx.py	2018-04-21 22:31:31.694426000 -0500
@@ -394,9 +394,9 @@
             self.env['LINKFLAGS'] += SCons.Util.CLVar(os.environ['LDFLAGS'])
 
         # Allow installation directories to be specified.
-        prefix = Script.ARGUMENTS.get('prefix', '/usr/local')
+        prefix = Script.ARGUMENTS.get('prefix', '%%PREFIX%%')
         if 'LIBDIR' in os.environ:
-            self.env['LIBDIR'] = os.path.relpath(os.environ['LIBDIR'], prefix)
+            self.env['LIBDIR'] = 'lib' # os.path.relpath(os.environ['LIBDIR'], prefix)
         if 'BINDIR' in os.environ:
             self.env['BINDIR'] = os.path.relpath(os.environ['BINDIR'], prefix)
         if 'SHAREDIR' in os.environ:
@@ -429,10 +429,10 @@
     def install_options(self):
         cachefile = os.path.join(self.get_cache_dir(), 'custom.py')
         vars = Script.Variables(cachefile)
-        vars.Add('prefix', 'Set to your install prefix', '/usr/local')
+        vars.Add('prefix', 'Set to your install prefix', '%%PREFIX%%')
         vars.Add('virtualize',
                  'Dynamically swap out the build directory when switching Git branches.', 1)
-        vars.Add('qtdir', 'Set to your QT4 directory', '/usr/share/qt4')
+        vars.Add('qtdir', 'Set to your QT4 directory', '%%LOCALBASE%%/share/qt4')
         vars.Add('qt_sqlite_plugin', 'Set to 1 to package the Qt SQLite plugin.'
                  '\n           Set to 0 if SQLite support is compiled into QtSQL.', 0)
         vars.Add('target',



# -*- coding: utf-8 -*-
from setuptools import setup

setup(
    name='pylast',
    version='%%PORTVERSION',
    description='A Python interface to Last.fm and Libre.fm',
    long_description='# pyLast\n\n[![PyPI version](https://img.shields.io/pypi/v/pylast.svg)](https://pypi.org/project/pylast/)\n[![Supported Python versions](https://img.shields.io/pypi/pyversions/pylast.svg)](https://pypi.org/project/pylast/)\n[![PyPI downloads](https://img.shields.io/pypi/dm/pylast.svg)](https://pypistats.org/packages/pylast)\n[![Test](https://github.com/pylast/pylast/workflows/Test/badge.svg)](https://github.com/pylast/pylast/actions)\n[![Coverage (Codecov)](https://codecov.io/gh/pylast/pylast/branch/main/graph/badge.svg)](https://codecov.io/gh/pylast/pylast)\n[![Code style: Black](https://img.shields.io/badge/code%20style-Black-000000.svg)](https://github.com/psf/black)\n[![DOI](https://zenodo.org/badge/7803088.svg)](https://zenodo.org/badge/latestdoi/7803088)\n\nA Python interface to [Last.fm](https://www.last.fm/) and other API-compatible websites\nsuch as [Libre.fm](https://libre.fm/).\n\nUse the pydoc utility for help on usage or see [tests/](tests/) for examples.\n\n## Installation\n\nInstall via pip:\n\n```sh\npython3 -m pip install pylast\n```\n\nInstall latest development version:\n\n```sh\npython3 -m pip install -U git+https://github.com/pylast/pylast\n```\n\nOr from requirements.txt:\n\n```txt\n-e https://github.com/pylast/pylast.git#egg=pylast\n```\n\nNote:\n\n* pyLast 5.1+ supports Python 3.7-3.11.\n* pyLast 5.0+ supports Python 3.7-3.10.\n* pyLast 4.3+ supports Python 3.6-3.10.\n* pyLast 4.0 - 4.2 supports Python 3.6-3.9.\n* pyLast 3.2 - 3.3 supports Python 3.5-3.8.\n* pyLast 3.0 - 3.1 supports Python 3.5-3.7.\n* pyLast 2.2 - 2.4 supports Python 2.7.10+, 3.4-3.7.\n* pyLast 2.0 - 2.1 supports Python 2.7.10+, 3.4-3.6.\n* pyLast 1.7 - 1.9 supports Python 2.7, 3.3-3.6.\n* pyLast 1.0 - 1.6 supports Python 2.7, 3.3-3.4.\n* pyLast 0.5 supports Python 2, 3.\n* pyLast < 0.5 supports Python 2.\n\n## Features\n\n * Simple public interface.\n * Access to all the data exposed by the Last.fm web services.\n * Scrobbling support.\n * Full object-oriented design.\n * Proxy support.\n * Internal caching support for some web services calls (disabled by default).\n * Support for other API-compatible networks like Libre.fm.\n\n\n## Getting started\n\nHere\'s some simple code example to get you started. In order to create any object from\npyLast, you need a `Network` object which represents a social music network that is\nLast.fm or any other API-compatible one. You can obtain a pre-configured one for Last.fm\nand use it as follows:\n\n```python\nimport pylast\n\n# You have to have your own unique two values for API_KEY and API_SECRET\n# Obtain yours from https://www.last.fm/api/account/create for Last.fm\nAPI_KEY = "b25b959554ed76058ac220b7b2e0a026"  # this is a sample key\nAPI_SECRET = "425b55975eed76058ac220b7b4e8a054"\n\n# In order to perform a write operation you need to authenticate yourself\nusername = "your_user_name"\npassword_hash = pylast.md5("your_password")\n\nnetwork = pylast.LastFMNetwork(\n    api_key=API_KEY,\n    api_secret=API_SECRET,\n    username=username,\n    password_hash=password_hash,\n)\n\n# Now you can use that object everywhere\ntrack = network.get_track("Iron Maiden", "The Nomad")\ntrack.love()\ntrack.add_tags(("awesome", "favorite"))\n\n# Type help(pylast.LastFMNetwork) or help(pylast) in a Python interpreter\n# to get more help about anything and see examples of how it works\n```\n\nMore examples in\n<a href="https://github.com/hugovk/lastfm-tools">hugovk/lastfm-tools</a> and\n[tests/](https://github.com/pylast/pylast/tree/main/tests).\n\n## Testing\n\nThe [tests/](https://github.com/pylast/pylast/tree/main/tests) directory contains\nintegration and unit tests with Last.fm, and plenty of code examples.\n\nFor integration tests you need a test account at Last.fm that will become cluttered with\ntest data, and an API key and secret. Either copy\n[example_test_pylast.yaml](example_test_pylast.yaml) to test_pylast.yaml and fill out\nthe credentials, or set them as environment variables like:\n\n```sh\nexport PYLAST_USERNAME=TODO_ENTER_YOURS_HERE\nexport PYLAST_PASSWORD_HASH=TODO_ENTER_YOURS_HERE\nexport PYLAST_API_KEY=TODO_ENTER_YOURS_HERE\nexport PYLAST_API_SECRET=TODO_ENTER_YOURS_HERE\n```\n\nTo run all unit and integration tests:\n\n```sh\npython3 -m pip install -e ".[tests]"\npytest\n```\n\nOr run just one test case:\n\n```sh\npytest -k test_scrobble\n```\n\nTo run with coverage:\n\n```sh\npytest -v --cov pylast --cov-report term-missing\ncoverage report # for command-line report\ncoverage html   # for HTML report\nopen htmlcov/index.html\n```\n\n## Logging\n\nTo enable from your own code:\n\n```python\nimport logging\nimport pylast\n\nlogging.basicConfig(level=logging.INFO)\n\n\nnetwork = pylast.LastFMNetwork(...)\n```\n\nTo enable from pytest:\n\n```sh\npytest --log-cli-level info -k test_album_search_images\n```\n\nTo also see data returned from the API, use `level=logging.DEBUG` or\n`--log-cli-level debug` instead.\n',
    author_email='"Amr Hassan <amr.hassan@gmail.com> and Contributors" <amr.hassan@gmail.com>',
    maintainer='Hugo van Kemenade',
    classifiers=[
        'Development Status :: 5 - Production/Stable',
        'License :: OSI Approved :: Apache Software License',
        'Programming Language :: Python :: 3',
        'Programming Language :: Python :: 3 :: Only',
        'Programming Language :: Python :: 3.7',
        'Programming Language :: Python :: 3.8',
        'Programming Language :: Python :: 3.9',
        'Programming Language :: Python :: 3.10',
        'Programming Language :: Python :: 3.11',
        'Programming Language :: Python :: Implementation :: CPython',
        'Programming Language :: Python :: Implementation :: PyPy',
        'Topic :: Internet',
        'Topic :: Multimedia :: Sound/Audio',
        'Topic :: Software Development :: Libraries :: Python Modules',
    ],
    install_requires=[
        'httpx',
        'importlib-metadata; python_version < "3.8"',
    ],
    extras_require={
        'tests': [
            'flaky',
            'pytest',
            'pytest-cov',
            'pytest-random-order',
            'pyyaml',
        ],
    },
    packages=[
        'pylast',
    ],
    package_dir={
        '': 'src',
    },
)



https://github.com/exaile/exaile/issues/770

--- xl/common.py.orig	2021-03-28 10:31:17 UTC
+++ xl/common.py
@@ -44,7 +44,12 @@ import weakref
 import urllib.request
 import weakref
 
-import bsddb3 as bsddb
+# TODO: Flip these around once we've done more testing with berkeleydb
+try:
+    import bsddb3 as bsddb
+except ImportError:
+    import berkeleydb as bsddb
+
 from gi.repository import Gio, GLib, GObject
 
 from xl import shelve_compat
@@ -394,8 +399,8 @@ def open_shelf(path):
     """
     shelve_compat.ensure_shelve_compat()
 
-    # As of Exaile 4, new DBs will only be created as Berkeley DB Hash databases
-    # using either bsddb3 (external) or bsddb (stdlib but sometimes removed).
+    # As of Exaile 4, DBs are created as Berkeley DB Hash databases using
+    # either berkeleydb or bsddb3.
     # Existing DBs created with other backends will be migrated to Berkeley DB.
     # We do this because BDB is generally considered more performant,
     # and because gdbm currently doesn't work at all in MSYS2.



--- config/qt5/__init__.py.orig	2021-07-27 23:51:08 UTC
+++ config/qt5/__init__.py
@@ -710,6 +710,13 @@ def generate(env):
     Action = SCons.Action.Action
     Builder = SCons.Builder.Builder
 
+    version = tuple(map(int, SCons.__version__.split('.')))
+
+    QT5_MOCDEFINES = \
+        '${_defines(QT5_MOCDEFPREFIX, CPPDEFINES, QT5_MOCDEFSUFFIX, __env__'
+    if (4, 2, 0) <= version: QT5_MOCDEFINES += ', TARGET, SOURCE'
+    QT5_MOCDEFINES += ')}'
+
     env['QT5DIR'] = _detect(env)
     env.Replace(
         QT5DIR  = _detect(env),
@@ -762,8 +769,7 @@ def generate(env):
         QT5_QRCCXXPREFIX = 'qrc_',
         QT5_MOCDEFPREFIX = '-D',
         QT5_MOCDEFSUFFIX = '',
-        QT5_MOCDEFINES = '${_defines(QT5_MOCDEFPREFIX, CPPDEFINES, '
-        'QT5_MOCDEFSUFFIX, __env__)}',
+        QT5_MOCDEFINES = QT5_MOCDEFINES,
         QT5_MOCCPPPATH = [],
         QT5_MOCINCFLAGS = '$( ${_concat(QT5_MOCINCPREFIX, QT5_MOCCPPPATH, '
         'INCSUFFIX, __env__, RDirs)} $)',



--- lib/cmmodule/twoList.py.orig	2021-04-04 22:42:53 UTC
+++ lib/cmmodule/twoList.py
@@ -5,7 +5,7 @@ from operator import mul,add,sub
 def check_list(v1,v2):
 	'''check if the length of two list is same'''
 	if v1.size != v2.size:
-		raise ValueError,"the lenght of both arrays must be the same"
+		raise ValueError("the length of both arrays must be the same")
 	pass
 
 def Add(v1,v2):
@@ -50,4 +50,4 @@ def Min(v1,v2):
 def euclidean_distance(v1,v2):
 	'''return euclidean distance'''                                                                                 
 	check_list(v1,v2)
-	return (sum((v1.__sub__(v2))**2) / v1.size)**0.5
\ No newline at end of file
+	return (sum((v1.__sub__(v2))**2) / v1.size)**0.5



--- lib/python/ctypes/ctypesgencore/parser/preprocessor.py.orig	2020-06-03 13:26:22 UTC
+++ lib/python/ctypes/ctypesgencore/parser/preprocessor.py
@@ -123,7 +123,8 @@ class PreprocessorParser(object):
     def __init__(self, options, cparser):
         self.defines = ["inline=", "__inline__=", "__extension__=",
                         "_Bool=uint8_t", "__const=const", "__asm__(x)=",
-                        "__asm(x)=", "CTYPESGEN=1"]
+                        "__asm(x)=", "CTYPESGEN=1",
+			"__attribute__(x)=", "__aligned(x)=", "_Noreturn="]
 
         # On OSX, explicitly add these defines to keep from getting syntax
         # errors in the OSX standard headers.



--- build/depends.py	2018-12-24 01:37:23.000000000 -0500
+++ build/depends.py	2018-12-26 22:17:54.336049000 -0500
@@ -12,7 +12,7 @@
         if not conf.CheckLib('portaudio'):
             raise Exception(
                 'Did not find libportaudio.a, portaudio.lib, or the PortAudio-v19 development header files.')
-        elif build.platform_is_linux:
+        elif build.platform_is_linux or build.platform_is_bsd:
             build.env.ParseConfig('pkg-config portaudio-2.0 --silence-errors --cflags --libs')
 
         # Turn on PortAudio support in Mixxx
@@ -74,7 +74,8 @@
 
         if (not conf.CheckLib('GLU') and
                 not conf.CheckLib('glu32') and
-                not conf.CheckCHeader('OpenGL/glu.h')):
+                not conf.CheckCHeader('OpenGL/glu.h') and
+                not conf.CheckCHeader('GL/glu.h')):
             raise Exception('Did not find GLU development files')
 
 
@@ -106,7 +107,7 @@
 class UPower(Dependence):
     """UPower is used to get battery measurements on Linux."""
     def configure(self, build, conf):
-        if not build.platform_is_linux:
+        if not build.platform_is_linux or not build.platform_is_bsd:
             return
         build.env.ParseConfig(
                 'pkg-config upower-glib --silence-errors --cflags --libs')
@@ -185,15 +186,17 @@
 
 class Qt(Dependence):
     DEFAULT_QT4DIRS = {'linux': '/usr/share/qt4',
-                       'bsd': '/usr/local/lib/qt4',
+                       'bsd': '%%LOCALBASE%%/share/qt4',
                        'osx': '/Library/Frameworks',
                        'windows': 'C:\\qt\\4.6.0'}
 
     DEFAULT_QT5DIRS64 = {'linux': '/usr/lib/x86_64-linux-gnu/qt5',
+			 'bsd': '%%LOCALBASE%%/lib/qt5',
                          'osx': '/Library/Frameworks',
                          'windows': 'C:\\qt\\5.11.1'}
 
     DEFAULT_QT5DIRS32 = {'linux': '/usr/lib/i386-linux-gnu/qt5',
+			 'bsd': '%%LOCALBASE%%/lib/qt5',
                          'osx': '/Library/Frameworks',
                          'windows': 'C:\\qt\\5.11.1'}
 
@@ -324,9 +327,17 @@
                 build.env.Append(CCFLAGS='-fPIC')
 
         elif build.platform_is_bsd:
-            build.env.Append(LIBS=qt_modules)
-            include_paths = ['$QTDIR/include/%s' % module
-                             for module in qt_modules]
+            qt_modules.extend(['QtDBus'])
+            if qt5:
+               qt5_modules = [w.replace('Qt', 'Qt5') for w in qt_modules]
+               build.env.Append(LIBS = qt5_modules)
+               build.env.Append(CCFLAGS='-fPIC')
+               include_paths = ['%%LOCALBASE%%/include/qt5/%s' % module
+                                for module in qt_modules]
+            else:
+               build.env.Append(LIBS = qt_modules)
+               include_paths = ['%%LOCALBASE%%/include/qt4/%s' % module
+                                for module in qt_modules]
             build.env.Append(CPPPATH=include_paths)
         elif build.platform_is_osx:
             qtdir = build.env['QTDIR']
@@ -492,7 +503,7 @@
         if not build.platform_is_windows and not (using_104_sdk or compiling_on_104):
             qtdir = build.env['QTDIR']
             framework_path = Qt.find_framework_libdir(qtdir, qt5)
-            if os.path.isdir(framework_path):
+            if framework_path and os.path.isdir(framework_path):
                 build.env.Append(LINKFLAGS="-L" + framework_path)
 
         # Mixxx requires C++11 support. Windows enables C++11 features by
@@ -586,7 +597,7 @@
         if env is None:
             env = build.env
 
-        if build.platform_is_linux:
+        if build.platform_is_linux or build.platform_is_bsd:
             # Try using system lib
             if conf.CheckForPKG('soundtouch', '2.0.0'):
                 # System Lib found
@@ -630,7 +641,7 @@
         # the files correctly. Adding this folder to the include path should fix
         # it, though might cause issues. This is safe to remove once we
         # deprecate Karmic support. rryan 2/2011
-        build.env.Append(CPPPATH='/usr/include/taglib/')
+        build.env.Append(CPPPATH='%%LOCALBASE%%/include/taglib/')
 
         if build.platform_is_windows and build.static_dependencies:
             build.env.Append(CPPDEFINES='TAGLIB_STATIC')
@@ -1343,7 +1354,6 @@
 
         if build.toolchain_is_gnu:
             # Default GNU Options
-            build.env.Append(CCFLAGS='-pipe')
             build.env.Append(CCFLAGS='-Wall')
             if build.compiler_is_clang:
                 # Quiet down Clang warnings about inconsistent use of override
@@ -1472,17 +1482,24 @@
                 build.env.Append(CPPPATH=['/opt/local/include'])
 
         elif build.platform_is_bsd:
+            qt5 = Qt.qt5_enabled(build)
+
+            if qt5:
+              qtdirectory = 'qt5'
+            else:
+              qtdirectory = 'qt4'
+
             build.env.Append(CPPDEFINES='__BSD__')
             build.env.Append(CPPPATH=['/usr/include',
-                                      '/usr/local/include',
-                                      '/usr/X11R6/include/'])
+                                      '%%LOCALBASE%%/include',
+                                      '%%LOCALBASE%%/include/'+ qtdirectory])
             build.env.Append(LIBPATH=['/usr/lib/',
-                                      '/usr/local/lib',
-                                      '/usr/X11R6/lib'])
+                                      '%%LOCALBASE%%/lib',
+                                      '%%LOCALBASE%%/lib/'+ qtdirectory])
             build.env.Append(LIBS='pthread')
             # why do we need to do this on OpenBSD and not on Linux?  if we
             # don't then CheckLib("vorbisfile") fails
-            build.env.Append(LIBS=['ogg', 'vorbis'])
+            build.env.Append(LIBS=['ogg', 'vorbis','X11'])
 
         # Define for things that would like to special case UNIX (Linux or BSD)
         if build.platform_is_bsd or build.platform_is_linux:
@@ -1515,7 +1532,7 @@
         # Say where to find resources on Unix. TODO(XXX) replace this with a
         # RESOURCE_PATH that covers Win and OSX too:
         if build.platform_is_linux or build.platform_is_bsd:
-            prefix = SCons.ARGUMENTS.get('prefix', '/usr/local')
+            prefix = SCons.ARGUMENTS.get('prefix', '%%PREFIX%%')
             share_path = os.path.join (prefix, build.env.get(
                 'SHAREDIR', default='share'), 'mixxx')
             build.env.Append(
@@ -1526,10 +1543,10 @@
                 CPPDEFINES=('UNIX_LIB_PATH', r'\"%s\"' % lib_path))
 
     def depends(self, build):
-        return [SoundTouch, ReplayGain, Ebur128Mit, PortAudio, PortMIDI, Qt, TestHeaders,
-                FidLib, SndFile, FLAC, OggVorbis, OpenGL, TagLib, ProtoBuf,
-                Chromaprint, RubberBand, SecurityFramework, CoreServices, Foundation, IOKit,
-                QtScriptByteArray, Reverb, FpClassify, PortAudioRingBuffer, OSXFilePathUrlBackport]
+        return [SoundTouch, ReplayGain, Ebur128Mit, PortAudio, Qt, TestHeaders,
+                 FidLib, SndFile, FLAC, OggVorbis, OpenGL, TagLib, ProtoBuf,
+                 Chromaprint, RubberBand, SecurityFramework, CoreServices, IOKit,
+                 QtScriptByteArray, Reverb, FpClassify, PortAudioRingBuffer]
 
     def post_dependency_check_configure(self, build, conf):
         """Sets up additional things in the Environment that must happen



--- asrun/system_command.py.orig	2017-07-13 07:40:52 UTC
+++ asrun/system_command.py
@@ -21,9 +21,9 @@
 This module defines syntaxes to run command lines.
 """
 
-from asrun.common.sysutils import on_linux
+from asrun.common.sysutils import on_windows
 
-if on_linux():
+if not on_windows():
     COMMAND = {
         'foreground' : '( %(cmd)s ) > /dev/null 2>&1',
         'background' : '( %(cmd)s ) > /dev/null 2>&1 &',
@@ -33,7 +33,7 @@ if on_linux():
         'not_follow_separ_stderr' : '( %(cmd)s ) > %(output)s 2> %(error)s',
         'rm_file' : '\\rm -f %(args)s',
         'rm_dirs' : '\\rm -rf %(args)s',
-        'copy' : 'cp -L -r %(args)s',
+        'copy' : 'cp -L -R %(args)s',
         'ping' : 'ping -c 1 -W %(timeout)s %(host)s',
         'shell_cmd' : "bash -c",
         'file' : "file %(args)s",



--- setup.py.orig	2017-04-19 05:48:10 UTC
+++ setup.py
@@ -60,7 +60,7 @@ def run_configure(option):
 
 
 def run_make_print_config():
-    stdout = subprocess.check_output(["make", "-s", "print-config"])
+    stdout = subprocess.check_output(["gmake", "-s", "print-config"])
     if IS_PYTHON3:
         stdout = stdout.decode("ascii")
 



from locust import HttpLocust, TaskSet, task, events

from gevent.coros import Semaphore
all_locusts_spawned = Semaphore()
all_locusts_spawned.acquire()

def on_hatch_complete(**kw):
    all_locusts_spawned.release()

events.hatch_complete += on_hatch_complete

class UserTasks(TaskSet):
    def on_start(self):
        all_locusts_spawned.wait()
        self.wait()
    
    @task
    def index(self):
        self.client.get("/")
    
class WebsiteUser(HttpLocust):
    host = "http://127.0.0.1:8089"
    min_wait = 2000
    max_wait = 5000
    task_set = UserTasks



--- setup.py.orig	2020-04-12 14:46:03 UTC
+++ setup.py
@@ -26,22 +26,6 @@ def main():
 
     cwd = os.path.abspath(os.path.dirname(__file__))
 
-    # install required numpy
-    p = subprocess.call([sys.executable, "-m", 'pip', 'install', f'numpy{numpy_requires}'],cwd=cwd)
-    if p != 0:
-        # Could be due to a too old pip version and build isolation, check that
-        try:
-            # Note, pip may not be installed or not have been used
-            import pip
-            if LooseVersion(pip.__version__) < LooseVersion('18.0.0'):
-                raise RuntimeError("Installing requirements failed. Possibly due "
-                                   "to `pip` being too old, found version {}, "
-                                   "needed is >= 18.0.0.".format(pip.__version__))
-            else:
-                raise RuntimeError("Installing requirements failed!")
-        except ImportError:
-            raise RuntimeError("Installing requirement failed! `pip` has to be installed!")
-        
     from numpy import get_include as numpy_get_include
     numpy_include_dir = [numpy_get_include()]
         



--- cura_app.py.orig	2020-02-28 16:06:57 UTC
+++ cura_app.py
@@ -1,4 +1,4 @@
-#!/usr/bin/env python3.8
+#!/usr/bin/env %%PYTHON_CMD%%
 
 # Copyright (c) 2022 Ultimaker B.V.
 # Cura is released under the terms of the LGPLv3 or higher.



--- UM/Platform.py.orig	2020-03-06 21:26:24 UTC
+++ UM/Platform.py
@@ -40,7 +40,7 @@ class Platform:
     __platform_type = PlatformType.Other
     if sys.platform == "win32":
         __platform_type = PlatformType.Windows
-    elif sys.platform == "linux":
+    elif (sys.platform == "linux" or "bsd" in sys.platform):
         __platform_type = PlatformType.Linux
     elif sys.platform == "darwin":
         __platform_type = PlatformType.OSX



--- build/features.py	2018-10-28 12:33:56.000000000 -0500
+++ build/features.py	2018-11-06 14:58:04.915561000 -0500
@@ -105,13 +105,24 @@
             # -pthread tells GCC to do the right thing regardless of system
             build.env.Append(CCFLAGS='-pthread')
             build.env.Append(LINKFLAGS='-pthread')
+        elif build.platform_is_bsd:
+            build.env.ParseConfig('pkg-config hidapi --silence-errors --cflags --libs')
 
+            conf.CheckLib(['pthread', 'libpthread'])
+            conf.CheckLib(['rt', 'librt'])
+
+            # -pthread tells GCC to do the right thing regardless of system
+            build.env.Append(CCFLAGS='-pthread')
+            build.env.Append(LINKFLAGS='-pthread')
         else:
             self.INTERNAL_LINK = True
             if build.platform_is_windows and not conf.CheckLib(['setupapi', 'libsetupapi']):
                 raise Exception('Did not find the setupapi library, exiting.')
             elif build.platform_is_osx:
                 build.env.AppendUnique(FRAMEWORKS=['IOKit', 'CoreFoundation'])
+            elif build.platform_is_bsd:
+                conf.CheckLib(['usb', 'libusb'])
+                conf.CheckLib(['usbhid', 'libusbhid'])
 
         build.env.Append(CPPDEFINES='__HID__')
         if self.INTERNAL_LINK:
@@ -129,7 +140,7 @@
                 # setupapi.
                 sources.append(
                     os.path.join(self.HIDAPI_INTERNAL_PATH, "windows/hid.c"))
-            elif build.platform_is_linux:
+            elif build.platform_is_linux or build.platform_is_bsd:
                 # hidapi compiles the libusb implementation by default on Linux
                 sources.append(
                     os.path.join(self.HIDAPI_INTERNAL_PATH, 'libusb/hid.c'))
@@ -147,14 +158,14 @@
     def enabled(self, build):
         # For now only make Bulk default on Linux only. Turn on for all
         # platforms after the 1.11.0 release.
-        is_default = 1 if build.platform_is_linux else 0
+        is_default = 1 if build.platform_is_linux or build.platform_is_bsd else 0
         build.flags['bulk'] = util.get_flags(build.env, 'bulk', is_default)
         if int(build.flags['bulk']):
             return True
         return False
 
     def add_options(self, build, vars):
-        is_default = 1 if build.platform_is_linux else 0
+        is_default = 1 if build.platform_is_linux or build.platform_is_bsd else 0
         vars.Add('bulk',
                  'Set to 1 to enable USB Bulk controller support.', is_default)
 
@@ -162,12 +173,15 @@
         if not self.enabled(build):
             return
 
-        build.env.ParseConfig(
-            'pkg-config libusb-1.0 --silence-errors --cflags --libs')
-        if (not conf.CheckLib(['libusb-1.0', 'usb-1.0']) or
-                not conf.CheckHeader('libusb-1.0/libusb.h')):
-            raise Exception(
-                'Did not find the libusb 1.0 development library or its header file, exiting!')
+        if build.platform_is_linux:
+            build.env.ParseConfig(
+                'pkg-config libusb-1.0 --silence-errors --cflags --libs')
+            if (not conf.CheckLib(['libusb-1.0', 'usb-1.0']) or
+                    not conf.CheckHeader('libusb-1.0/libusb.h')):
+                raise Exception(
+                    'Did not find the libusb 1.0 development library or its header file, exiting!')
+        elif build.platform_is_bsd:
+            conf.CheckLib(['usb', 'libusb'])
 
         build.env.Append(CPPDEFINES='__BULK__')
 
@@ -396,7 +410,7 @@
         # If there is no system vamp-hostsdk is installed or if the version
         # of the installed vamp-hostsdk is less than the bundled version,
         # then we'll directly link the bundled vamp-hostsdk
-        if not conf.CheckLib('vamp-hostsdk') or not conf.CheckForPKG('vamp-plugin-sdk', '2.7.1'):
+        if not conf.CheckLib('vamp-hostsdk') or not conf.CheckForPKG('vamp-sdk', '2.7.1'):
             # For header includes
             build.env.Append(CPPPATH=[self.INTERNAL_VAMP_PATH])
             self.INTERNAL_LINK = True
@@ -409,7 +423,7 @@
         # FFTW3 support
         have_fftw3_h = conf.CheckHeader('fftw3.h')
         have_fftw3 = conf.CheckLib('fftw3', autoadd=False)
-        if have_fftw3_h and have_fftw3 and build.platform_is_linux:
+        if have_fftw3_h and have_fftw3 and (build.platform_is_linux or build.platform_is_bsd) :
             build.env.Append(CPPDEFINES='HAVE_FFTW3')
             build.env.ParseConfig(
                 'pkg-config fftw3 --silence-errors --cflags --libs')
@@ -1295,7 +1309,7 @@
             return ["util/battery/batterywindows.cpp"]
         elif build.platform_is_osx:
             return ["util/battery/batterymac.cpp"]
-        elif build.platform_is_linux:
+        elif build.platform_is_linux or build.platform_is_bsd:
             return ["util/battery/batterylinux.cpp"]
         else:
             raise Exception('Battery support is not implemented for the target platform.')



import os

from locust import HttpLocust, TaskSet, task
from locust.clients import HttpSession

class MultipleHostsLocust(HttpLocust):
    abstract = True
    
    def __init__(self, *args, **kwargs):
        super(MultipleHostsLocust, self).__init__(*args, **kwargs)
        self.api_client = HttpSession(base_url=os.environ["API_HOST"])
    

class UserTasks(TaskSet):
    # but it might be convenient to use the @task decorator
    @task
    def index(self):
        self.locust.client.get("/")
    
    @task
    def index_other_host(self):
        self.locust.api_client.get("/stats/requests")
    
class WebsiteUser(MultipleHostsLocust):
    """
    Locust user class that does requests to the locust web server running on localhost
    """
    host = "http://127.0.0.1:8089"
    min_wait = 2000
    max_wait = 5000
    task_set = UserTasks



--- doc/source/_util/cql.py.orig	2020-10-03 15:05:17 UTC
+++ doc/source/_util/cql.py
@@ -26,7 +26,6 @@ from pygments.lexer import Lexer, RegexLexer, do_inser
 from pygments.token import Punctuation, Whitespace, Error, \
     Text, Comment, Operator, Keyword, Name, String, Number, Generic, Literal
 from pygments.lexers import get_lexer_by_name, ClassNotFound
-from pygments.util import iteritems
 
 __all__ = [ 'CQLLexer' ]
 



--- UM/Qt/QtRenderer.py.orig	2020-03-08 12:13:28 UTC
+++ UM/Qt/QtRenderer.py
@@ -129,7 +129,7 @@ class QtRenderer(Renderer):
         if not self._initialized:
             self._initialize()
 
-        self._gl.glViewport(0, 0, self._viewport_width, self._viewport_height)
+        self._gl.glViewport(0, 0, int(self._viewport_width), int(self._viewport_height))
         self._gl.glClearColor(self._background_color.redF(), self._background_color.greenF(), self._background_color.blueF(), self._background_color.alphaF())
         self._gl.glClear(self._gl.GL_COLOR_BUFFER_BIT | self._gl.GL_DEPTH_BUFFER_BIT)
         self._gl.glClearColor(0.0, 0.0, 0.0, 0.0)
@@ -157,7 +157,7 @@ class QtRenderer(Renderer):
 
         for render_pass in self.getRenderPasses():
             width, height = render_pass.getSize()
-            self._gl.glViewport(0, 0, width, height)
+            self._gl.glViewport(0, 0, int(width), int(height))
             render_pass.render()
 
     def reRenderLast(self):



# This locust test script example will simulate a user 
# browsing the Locust documentation on https://docs.locust.io/

import random
from locust import HttpLocust, TaskSet, task
from pyquery import PyQuery


class BrowseDocumentation(TaskSet):
    def on_start(self):
        # assume all users arrive at the index page
        self.index_page()
        self.urls_on_current_page = self.toc_urls
    
    @task(10)
    def index_page(self):
        r = self.client.get("/")
        pq = PyQuery(r.content)
        link_elements = pq(".toctree-wrapper a.internal")
        self.toc_urls = [
            l.attrib["href"] for l in link_elements
        ]
    
    @task(50)
    def load_page(self, url=None):
        url = random.choice(self.toc_urls)
        r = self.client.get(url)
        pq = PyQuery(r.content)
        link_elements = pq("a.internal")
        self.urls_on_current_page = [
            l.attrib["href"] for l in link_elements
        ]
    
    @task(30)
    def load_sub_page(self):
        url = random.choice(self.urls_on_current_page)
        r = self.client.get(url)


class AwesomeUser(HttpLocust):
    task_set = BrowseDocumentation
    host = "https://docs.locust.io/en/latest/"
    
    # we assume someone who is browsing the Locust docs, 
    # generally has a quite long waiting time (between 
    # 20 and 600 seconds), since there's a bunch of text 
    # on each page
    min_wait = 20  * 1000
    max_wait = 600 * 1000



--- build/qt5.py.orig	2020-05-15 21:26:10 UTC
+++ build/qt5.py
@@ -43,7 +43,7 @@ import SCons.Scanner
 import SCons.Tool
 import SCons.Util
 
-class ToolQt5Warning(SCons.Warnings.Warning):
+class ToolQt5Warning(SCons.Warnings.SConsWarning):
     pass
 
 class GeneratedMocFileNotIncluded(ToolQt5Warning):



--- cura/OAuth2/KeyringAttribute.py.orig	2022-04-28 04:59:10 UTC
+++ cura/OAuth2/KeyringAttribute.py
@@ -5,7 +5,7 @@ from typing import Type, TYPE_CHECKING, Optional, List
 from io import BlockingIOError
 import keyring
 from keyring.backend import KeyringBackend
-from keyring.errors import NoKeyringError, PasswordSetError, KeyringLocked
+from keyring.errors import PasswordSetError, KeyringLocked
 
 from UM.Logger import Logger
 
